Skip to contents

.. content for ..

Usage

assemble_partialised(obj, reduced, resids = TRUE)

Arguments

obj

The result of a previous 'partialise'

reduced

A formula, the right-hand-side of which contains the terms that will be used to predict the response

resids

Boolean indicating whether to include the residuals (default) or not

Value

A matrix of the same dimensions as the original input to 'partialise'

See also

Other partial: dropped_terms(), partialise()

Author

Gavin Kelly