Skip to contents

Compare a partialised object with the terms in a reduced model

Usage

dropped_terms(obj, reduced)

Arguments

obj

The result of a previous 'partialise'

reduced

A formula, the right-hand-side of which contains the terms that will be used to predict the response

Value

A character vector of terms that will have been 'dropped'

Details

Report the terms that were in the original model used to partialise the data, but are omitted from the reduced model (and so will their effect will be removed from any reconstruction)

See also

Other partial: assemble_partialised(), partialise()

Author

Gavin Kelly