Skip to contents

Generate text files require for Biologic

Usage

export_biologic(result_object, path)

Arguments

result_object

Path to the rds of the result object

path

Where to write the files for Biologic to read

Value

nothing

Details

The visualisation part of 'Biologic' requires a set of text files which represent the differential results and the models and contrasts that were used to derive the results. This function generates them from a previous run of the pipeline.

Author

Gavin Kelly