Skip to contents

Text file of assay data

Usage

write_assay(ddsList, aname = "vst", p)

Arguments

ddsList

A list of DESeq2::DESeqDataSet-class() objects

assay

The assay to be output (or 'norm' for normalised counts)

path

Where to put the text files

suffix

Additional identifier information for the filename

formula

The model that will be used to estimate the normalisation offsets

terms_to_remove

The 'Terms' estimated from the above model that will be removed (subtracted) from values of the assay.

Value

A list of file paths to the excel files

Details

Write all sample data, with the colData as a header

Author

Gavin Kelly