Produce quarto headings corresponding to the data/model hierarchy
Source:R/markdown.r
dmc_heading.RdCreate markdown headings at a given level for either a dataset or a model. Use the short name, long name, and description as appropriate.
Arguments
- obj
Either a list of DESeqDataSet objects, or a Data/Model/Comparison hierarchy
- depth
A string denoting the markdown heading prefix
- numbered
Do the headings need to be numbered
- describe
Print the description text as the first paragraph of the section?
- dataset
The name of the dataset to use.
- model
If the model is to be used to generate the heading info, give the name.