Compare a partialised object with the terms in a reduced model
Details
Report the terms that were in the original model used to partialise the data, but are omitted from the reduced model (and so will their effect will be removed from any reconstruction)
See also
Other partial:
assemble_partialised(),
partialise()