Calculate the partial components predicted by a model
Usage
partialise(obj, ...)
# S3 method for class 'matrix'
partialise(obj, cdata, fml, influence = TRUE)
# S3 method for class 'DESeqDataSet'
partialise(obj, assay = "vst", influence = TRUE)Details
Given a matrix-like object, calculate the amount that each term in a design formula contributes to the outcome. This, along with each sample's residual error, allows us to reconstruct the original matrix, in a customised way that includes or removes the contribution of specific variables.
See also
assemble_partialised() for how to construct a matrix from the parts
Other partial:
assemble_partialised(),
dropped_terms()
Other partial:
assemble_partialised(),
dropped_terms()
Other partial:
assemble_partialised(),
dropped_terms()