Text file of assay data
Arguments
- ddsList
A list of
DESeq2::DESeqDataSet-class()objects- assay
The assay to be output (or 'norm' for normalised counts)
- path
Where to put the text files
- suffix
Additional identifier information for the filename
- formula
The model that will be used to estimate the normalisation offsets
- terms_to_remove
The 'Terms' estimated from the above model that will be removed (subtracted) from values of the assay.